@@ -1,4 +1,4 @@
-# $Id: wbug.py 1173 2014-12-07 15:25:10Z mwall $
+# $Id: wbug.py 1331 2015-06-23 14:14:15Z mwall $
 # Copyright 2013 Matthew Wall
 
 """
@@ -84,7 +84,7 @@ import weewx.restx
 import weewx.units
 from weeutil.weeutil import to_bool, accumulateLeaves, startOfDayUTC
 
-VERSION = "0.4"
+VERSION = "0.5"
 
 if weewx.__version__ < "3":
     raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
@@ -271,11 +271,11 @@ class WeatherBugThread(weewx.restx.RESTThread):
             (from_unit, _) = weewx.units.getStandardUnitType(
                 record['usUnits'], 'outTemp')
             if 'outTempMax' in rec and rec['outTempMax']:
-                from_t = (rec['outTempMax'], from_unit, 'group_rain')
-                rec['outTempMax'] = weewx.units.convert(from_t, 'inch')[0]
+                from_t = (rec['outTempMax'], from_unit, 'group_temperature')
+                rec['outTempMax'] = weewx.units.convert(from_t, 'degree_F')[0]
             if 'outTempMin' in rec and rec['outTempMin']:
-                from_t = (rec['outTempMin'], from_unit, 'group_rain')
-                rec['outTempMin'] = weewx.units.convert(from_t, 'inch')[0]
+                from_t = (rec['outTempMin'], from_unit, 'group_temperature')
+                rec['outTempMin'] = weewx.units.convert(from_t, 'degree_F')[0]
         return rec
 
     def check_response(self, response):
